==> apache-camel-3.18.1-src.zip: apache-camel-3.18.1/core/camel-core/src/test/java/org/apache/camel/impl/RoutePolicyRefCallbackTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.impl;

import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.spi.Registry;

/**
 *
 */
public class RoutePolicyRefCallbackTest extends RoutePolicyCallbackTest {

    @Override
    protected Registry createRegistry() throws Exception {
        Registry registry = super.createRegistry();
        registry.bind("myPolicy", policy);
        return registry;
    }

    @Override
    protected MyRoutePolicy getAndInitMyRoutePolicy() {
        return context.getRegistry().lookupByNameAndType("myPolicy", MyRoutePolicy.class);
    }

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                from("direct:start").routeId("foo").routePolicyRef("myPolicy").to("mock:result");
            }
        };
    }
}

==> apache-camel-4.5.0-src.zip: apache-camel-4.5.0/core/camel-core/src/test/java/org/apache/camel/impl/RoutePolicyRefCallbackTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.impl;

import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.spi.Registry;

/**
 *
 */
public class RoutePolicyRefCallbackTest extends RoutePolicyCallbackTest {

    @Override
    protected Registry createCamelRegistry() throws Exception {
        Registry registry = super.createCamelRegistry();
        registry.bind("myPolicy", policy);
        return registry;
    }

    @Override
    protected MyRoutePolicy getAndInitMyRoutePolicy() {
        return context.getRegistry().lookupByNameAndType("myPolicy", MyRoutePolicy.class);
    }

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                from("direct:start").routeId("foo").routePolicyRef("myPolicy").to("mock:result");
            }
        };
    }
}
